@@ -1,4 +1,4 @@
-// Copyright 2015 - 2021, GIBIS-Unifesp and the wiRedPanda contributors
+// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "itemwithid.h"
@@ -9,17 +9,17 @@ ItemWithId::ItemWithId()
     ElementFactory::addItem(this);
 }
 
+ItemWithId::~ItemWithId()
+{
+    ElementFactory::removeItem(this);
+}
+
 int ItemWithId::id() const
 {
     return m_id;
 }
 
-void ItemWithId::setId(int id)
+void ItemWithId::setId(const int id)
 {
     m_id = id;
 }
-
-ItemWithId::~ItemWithId()
-{
-    ElementFactory::removeItem(this);
-}
\ No newline at end of file
