@@ -1,4 +1,4 @@
-// Copyright 2015 - 2021, GIBIS-Unifesp and the wiRedPanda contributors
+// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logicdemux.h"
@@ -8,18 +8,24 @@ LogicDemux::LogicDemux()
 {
 }
 
-void LogicDemux::_updateLogic(const std::vector<bool> &inputs)
+void LogicDemux::updateLogic()
 {
-    bool data = inputs[0];
-    bool choice = inputs[1];
+    if (!updateInputs()) {
+        return;
+    }
+
+    const bool data = m_inputValues.at(0);
+    const bool choice = m_inputValues.at(1);
 
     bool out0 = false;
     bool out1 = false;
+
     if (!choice) {
         out0 = data;
     } else {
         out1 = data;
     }
+
     setOutputValue(0, out0);
     setOutputValue(1, out1);
-}
\ No newline at end of file
+}
